==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/userSession/MapAuthenticatedClientSessionEntityFieldDelegate.java <==
package org.keycloak.models.map.userSession;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticatedClientSessionEntityFieldDelegate extends org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity.AbstractAuthenticatedClientSessionEntity implements org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> entityFieldDelegate;
    public MapAuthenticatedClientSessionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthMethod() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.AUTH_METHOD);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthMethod(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.AUTH_METHOD, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRedirectUri() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.REDIRECT_URI);
    }
    @SuppressWarnings("unchecked") @Override public void setRedirectUri(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.REDIRECT_URI, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAction() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.ACTION);
    }
    @SuppressWarnings("unchecked") @Override public void setAction(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.ACTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getNote(String p0) {
        return (String) entityFieldDelegate.mapGet(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeNote(String p0) {
        return (Boolean) entityFieldDelegate.mapRemove(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public String getCurrentRefreshToken() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CURRENT_REFRESH_TOKEN);
    }
    @SuppressWarnings("unchecked") @Override public void setCurrentRefreshToken(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CURRENT_REFRESH_TOKEN, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getCurrentRefreshTokenUseCount() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CURRENT_REFRESH_TOKEN_USE_COUNT);
    }
    @SuppressWarnings("unchecked") @Override public void setCurrentRefreshTokenUseCount(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CURRENT_REFRESH_TOKEN_USE_COUNT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isOffline() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.OFFLINE);
    }
    @SuppressWarnings("unchecked") @Override public void setOffline(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.OFFLINE, p0);
    }
}

==> keycloak-model-map-22.0.0-sources.jar: org/keycloak/models/map/userSession/MapAuthenticatedClientSessionEntityFieldDelegate.java <==
package org.keycloak.models.map.userSession;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticatedClientSessionEntityFieldDelegate extends org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity.AbstractAuthenticatedClientSessionEntity implements org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> entityFieldDelegate;
    public MapAuthenticatedClientSessionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthMethod() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.AUTH_METHOD);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthMethod(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.AUTH_METHOD, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRedirectUri() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.REDIRECT_URI);
    }
    @SuppressWarnings("unchecked") @Override public void setRedirectUri(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.REDIRECT_URI, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAction() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.ACTION);
    }
    @SuppressWarnings("unchecked") @Override public void setAction(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.ACTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getNote(String p0) {
        return (String) entityFieldDelegate.mapGet(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeNote(String p0) {
        return (Boolean) entityFieldDelegate.mapRemove(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public String getCurrentRefreshToken() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CURRENT_REFRESH_TOKEN);
    }
    @SuppressWarnings("unchecked") @Override public void setCurrentRefreshToken(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CURRENT_REFRESH_TOKEN, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getCurrentRefreshTokenUseCount() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CURRENT_REFRESH_TOKEN_USE_COUNT);
    }
    @SuppressWarnings("unchecked") @Override public void setCurrentRefreshTokenUseCount(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.CURRENT_REFRESH_TOKEN_USE_COUNT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isOffline() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.OFFLINE);
    }
    @SuppressWarnings("unchecked") @Override public void setOffline(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntityFields.OFFLINE, p0);
    }
}
